@@ -75,7 +75,7 @@ def fill_annotation(
         draw.rectangle(xy, fill=color)
 
     elif data_type == "Points":
-        # Polygon
+        # Polygon or Polyline
         xy = [(e["x"], e["y"]) for e in data["points"]]
         draw.polygon(xy, fill=color)
 
@@ -114,7 +114,7 @@ def fill_annotation_list(
     # 下層レイヤにあるアノテーションから順に画像化する
     # reversed関数を使う理由：`simple_annotation.details`は上層レイヤのアノテーションから順に格納されているため
     if label_name_list is not None:
-        annotation_list = [e for e in reversed(simple_annotation.details) if e.label in label_name_list]
+        annotation_list = [elm for elm in reversed(simple_annotation.details) if elm.label in label_name_list]
     else:
         annotation_list = list(reversed(simple_annotation.details))
 
@@ -191,8 +191,6 @@ def write_annotation_images_from_path(
     output_dir_path: Path,
     image_size: Optional[InputDataSize] = None,
     input_data_dict: Optional[Dict[str, InputData]] = None,
-    metadata_key_of_image_width: Optional[str] = None,
-    metadata_key_of_image_height: Optional[str] = None,
     output_image_extension: str = "png",
     background_color: Optional[Any] = None,
     label_name_list: Optional[List[str]] = None,
@@ -208,8 +206,6 @@ def write_annotation_images_from_path(
         output_dir_path: 画像の出力先のディレクトリのパス
         image_size: 画像のサイズ. Tuple[width, height]
         input_data_dict: 入力データのDict(key:input_data_id, value:InputData)
-        metadata_key_of_image_width: 入力データのメタデータのキー（画像width)
-        metadata_key_of_image_height: 入力データのメタデータのキー（画像height)
         output_image_extension: 出力する画像ファイルの拡張子. 指定しない場合は"png"です。
         background_color: アノテーション画像の背景色.
             (ex) "rgb(173, 216, 230)", "#add8e6", "lightgray", (173,216,230)
@@ -224,36 +220,29 @@ def write_annotation_images_from_path(
     """
 
     def _get_image_size(input_data_id: str) -> Optional[InputDataSize]:
+        def _get_image_size_from_system_metadata():
+            # 入力データの`input_data.system_metadata.original_resolution`を参照して、画像サイズを決める。
+            original_resolution = input_data["system_metadata"]["original_resolution"]
+            if original_resolution is not None and (
+                original_resolution.get("width") is not None and original_resolution.get("height") is not None
+            ):
+                return original_resolution.get("width"), original_resolution.get("height")
+            else:
+                logger.warning(
+                    f"input_data_id={input_data_id}のプロパティ" f"`system_metadata.original_resolution`には画像サイズが設定されていません。"
+                )
+                return None
+
         if image_size is not None:
             return image_size
         elif input_data_dict is not None:
-            if metadata_key_of_image_width is not None and metadata_key_of_image_height is not None:
-                input_data = input_data_dict[input_data_id]
-                if input_data is None:
-                    logger.warning(f"input_data_id={input_data_id}の入力データは存在しなかったので、スキップします。")
-                    return None
-                metadata = input_data["metadata"]
-                if metadata is not None and (
-                    metadata_key_of_image_width in metadata and metadata_key_of_image_height in metadata
-                ):
-                    try:
-                        return (int(metadata[metadata_key_of_image_width]), int(metadata[metadata_key_of_image_height]))
-                    except ValueError as e:
-                        logger.warning(f"input_data_id={input_data_id}の入力データのメタデータの数値変換に失敗しました。{e}")
-                        return None
+            input_data = input_data_dict.get(input_data_id)
+            if input_data is None:
+                logger.warning(f"input_data_id={input_data_id}の入力データは存在しなかったので、スキップします。")
+                return None
+
+            return _get_image_size_from_system_metadata()
 
-                else:
-                    logger.warning(
-                        f"input_data_id={input_data_id}の入力データのメタデータに、"
-                        f"{metadata_key_of_image_width}, {metadata_key_of_image_height} というキーが存在しなかったので、"
-                        f"スキップします。"
-                    )
-                    return None
-            else:
-                raise ValueError(
-                    f"引数`input_data_dict`がNoneでない場合は、"
-                    f"`metadata_key_of_image_width`と`metadata_key_of_image_height`はnot Noneである必要があります。"
-                )
         else:
             raise ValueError(f"引数`image_size`または`input_data_dict`のどちらかはnot Noneである必要があります。")
 
