@@ -9,7 +9,6 @@ import pandas
 import annofabcli
 from annofabcli.common.cli import COMMAND_LINE_ERROR_STATUS_CODE, get_list_from_args
 from annofabcli.common.utils import print_csv, print_json
-from annofabcli.stat_visualization.merge_performance_per_date import create_df_merged_performance_per_date
 from annofabcli.stat_visualization.write_linegraph_per_user import write_linegraph_per_user
 from annofabcli.stat_visualization.write_performance_scatter_per_user import write_performance_scatter_per_user
 from annofabcli.stat_visualization.write_task_histogram import write_task_histogram
@@ -19,7 +18,6 @@ from annofabcli.statistics.csv import (
     FILENAME_PERFORMANCE_PER_FIRST_ANNOTATION_STARTED_DATE,
     FILENAME_PERFORMANCE_PER_USER,
     FILENAME_TASK_LIST,
-    Csv,
 )
 from annofabcli.statistics.visualization.dataframe.user_performance import UserPerformance, WholePerformance
 from annofabcli.statistics.visualization.dataframe.whole_productivity_per_date import (
@@ -30,6 +28,33 @@ from annofabcli.statistics.visualization.dataframe.whole_productivity_per_date i
 logger = logging.getLogger(__name__)
 
 
+def create_merged_performance_per_date(csv_path_list: List[Path]) -> WholeProductivityPerCompletedDate:
+    """
+    `日毎の生産量と生産性.csv` をマージしたDataFrameを返す。
+    Args:
+        csv_path_list:
+    Returns:
+    """
+    df_list: List[pandas.DataFrame] = []
+    for csv_path in csv_path_list:
+        if csv_path.exists():
+            df = pandas.read_csv(str(csv_path))
+            df_list.append(df)
+        else:
+            logger.warning(f"{csv_path} は存在しませんでした。")
+            continue
+
+    if len(df_list) == 0:
+        logger.warning(f"マージ対象のCSVファイルは存在しませんでした。")
+        return pandas.DataFrame()
+
+    sum_obj = WholeProductivityPerCompletedDate(df_list[0])
+    for df in df_list[1:]:
+        sum_obj = WholeProductivityPerCompletedDate.merge(sum_obj, WholeProductivityPerCompletedDate(df))
+
+    return sum_obj
+
+
 def merge_visualization_dir(  # pylint: disable=too-many-statements
     project_dir_list: List[Path],
     output_dir: Path,
@@ -62,8 +87,8 @@ def merge_visualization_dir(  # pylint: disable=too-many-statements
 
     def execute_merge_performance_per_date():
         performance_per_date_csv_list = [dir / FILENAME_PERFORMANCE_PER_DATE for dir in project_dir_list]
-        df_per_date = create_df_merged_performance_per_date(performance_per_date_csv_list)
-        WholeProductivityPerCompletedDate.to_csv(df_per_date, output_dir / FILENAME_PERFORMANCE_PER_DATE)
+        obj = create_merged_performance_per_date(performance_per_date_csv_list)
+        obj.to_csv(output_dir / FILENAME_PERFORMANCE_PER_DATE)
 
     def merge_performance_per_first_annotation_started_date():
         csv_list = [dir / FILENAME_PERFORMANCE_PER_FIRST_ANNOTATION_STARTED_DATE for dir in project_dir_list]
@@ -80,15 +105,15 @@ def merge_visualization_dir(  # pylint: disable=too-many-statements
             logger.warning(f"マージ対象のCSVファイルは存在しませんでした。")
             return
 
-        sum_df = df_list[0]
+        sum_obj = WholeProductivityPerFirstAnnotationStartedDate(df_list[0])
         for df in df_list[1:]:
-            sum_df = WholeProductivityPerFirstAnnotationStartedDate.merge(sum_df, df)
+            sum_obj = WholeProductivityPerFirstAnnotationStartedDate.merge(
+                sum_obj, WholeProductivityPerFirstAnnotationStartedDate(df)
+            )
 
-        WholeProductivityPerFirstAnnotationStartedDate.to_csv(
-            sum_df, output_dir / FILENAME_PERFORMANCE_PER_FIRST_ANNOTATION_STARTED_DATE
-        )
+        sum_obj.to_csv(output_dir / FILENAME_PERFORMANCE_PER_FIRST_ANNOTATION_STARTED_DATE)
 
-        WholeProductivityPerFirstAnnotationStartedDate.plot(sum_df, output_dir / "line-graph/折れ線-横軸_教師付開始日-全体.html")
+        sum_obj.plot(output_dir / "line-graph/折れ線-横軸_教師付開始日-全体.html")
 
     def merge_task_list() -> pandas.DataFrame:
         list_df = []
@@ -103,27 +128,15 @@ def merge_visualization_dir(  # pylint: disable=too-many-statements
         df = pandas.concat(list_df, axis=0)
         return df
 
-    def write_csv_for_summary(df_task: pandas.DataFrame) -> None:
-        """
-        タスク関係のCSVを出力する。
-        """
-        csv_obj.write_task_count_summary(df_task)
-        csv_obj.write_worktime_summary(df_task)
-        csv_obj.write_count_summary(df_task)
-
     def write_info_json() -> None:
         info = {"target_dir_list": [str(e) for e in project_dir_list]}
         print_json(info, is_pretty=True, output=str(output_dir / "info.json"))
 
-    # CSV生成
-    csv_obj = Csv(str(output_dir))
-
     execute_merge_performance_per_user()
     execute_merge_performance_per_date()
     merge_performance_per_first_annotation_started_date()
     df_task = merge_task_list()
     print_csv(df_task, output=str(output_dir / FILENAME_TASK_LIST))
-    write_csv_for_summary(df_task)
 
     # HTML生成
     write_performance_scatter_per_user(
@@ -137,9 +150,7 @@ def merge_visualization_dir(  # pylint: disable=too-many-statements
         minimal_output=minimal_output,
         user_id_list=user_id_list,
     )
-    write_task_histogram(
-        csv=output_dir / FILENAME_TASK_LIST, output_dir=output_dir / "histogram", minimal_output=minimal_output
-    )
+    write_task_histogram(csv=output_dir / FILENAME_TASK_LIST, output_dir=output_dir / "histogram")
 
     # info.jsonを出力
     write_info_json()
