@@ -10,7 +10,7 @@ import pandas
 import annofabcli
 from annofabcli.common.cli import AbstractCommandLineWithoutWebapiInterface, get_list_from_args
 from annofabcli.common.utils import print_csv, read_multiheader_csv
-from annofabcli.statistics.csv import FILENAME_PEFORMANCE_PER_USER
+from annofabcli.statistics.csv import FILENAME_PERFORMANCE_PER_USER
 
 logger = logging.getLogger(__name__)
 
@@ -140,7 +140,7 @@ def create_rating_df(
         if not project_dir.is_dir():
             continue
 
-        csv = project_dir / FILENAME_PEFORMANCE_PER_USER
+        csv = project_dir / FILENAME_PERFORMANCE_PER_USER
         project_title = project_dir.name
         if not csv.exists():
             logger.warning(f"{csv} は存在しないのでスキップします。")
@@ -359,7 +359,7 @@ def create_user_df(target_dir: Path) -> pandas.DataFrame:
         if not project_dir.is_dir():
             continue
 
-        csv = project_dir / FILENAME_PEFORMANCE_PER_USER
+        csv = project_dir / FILENAME_PERFORMANCE_PER_USER
         if not csv.exists():
             logger.warning(f"{csv} は存在しないのでスキップします。")
             continue
@@ -407,7 +407,7 @@ def parse_args(parser: argparse.ArgumentParser):
         "--dir",
         type=Path,
         required=True,
-        help=f"プロジェクトディレクトリが存在するディレクトリを指定してください。プロジェクトディレクトリ内の ``{FILENAME_PEFORMANCE_PER_USER}`` というファイルを読み込みます。",
+        help=f"プロジェクトディレクトリが存在するディレクトリを指定してください。プロジェクトディレクトリ内の ``{FILENAME_PERFORMANCE_PER_USER}`` というファイルを読み込みます。",
     )
 
     parser.add_argument(
@@ -421,7 +421,7 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.add_argument(
         "--threshold_worktime",
         type=int,
-        default=0,
+        default=10,
         help="作業時間の閾値。この時間以下の作業者は除外する。 ``threshold_task_count`` とはOR条件で絞り込まれる。",
     )
     parser.add_argument(
@@ -433,6 +433,7 @@ def parse_args(parser: argparse.ArgumentParser):
     parser.add_argument(
         "--threshold_deviation_user_count",
         type=int,
+        default=3,
         help="偏差値を出す際、プロジェクト内の作業者がしきい値以下であれば、偏差値を算出しない。",
     )
     parser.add_argument("-o", "--output_dir", required=True, type=Path, help="出力ディレクトリ")
