@@ -1,5 +1,4 @@
 import argparse
-import importlib
 import logging.handlers
 import re
 import sys
@@ -11,17 +10,16 @@ from typing import Any, Callable, Collection, List, Optional
 
 import annofabapi
 import pandas
-from annofabapi.models import ProjectMemberRole, TaskPhase
+from annofabapi.models import ProjectMemberRole
 from dataclasses_json import DataClassJsonMixin
 
 import annofabcli
-from annofabcli import AnnofabApiFacade
 from annofabcli.common.cli import (
     COMMAND_LINE_ERROR_STATUS_CODE,
     AbstractCommandLineInterface,
     build_annofabapi_resource_and_login,
 )
-from annofabcli.common.facade import TaskQuery
+from annofabcli.common.facade import AnnofabApiFacade, TaskQuery
 from annofabcli.stat_visualization.merge_visualization_dir import merge_visualization_dir
 from annofabcli.statistics.csv import (
     FILENAME_PERFORMANCE_PER_DATE,
@@ -30,7 +28,7 @@ from annofabcli.statistics.csv import (
     Csv,
 )
 from annofabcli.statistics.database import Database, Query
-from annofabcli.statistics.table import AggregationBy, Table
+from annofabcli.statistics.table import Table
 from annofabcli.statistics.visualization.dataframe.cumulative_productivity import (
     AcceptorCumulativeProductivity,
     AnnotatorCumulativeProductivity,
@@ -41,6 +39,7 @@ from annofabcli.statistics.visualization.dataframe.productivity_per_date import
     AnnotatorProductivityPerDate,
     InspectorProductivityPerDate,
 )
+from annofabcli.statistics.visualization.dataframe.task import Task
 from annofabcli.statistics.visualization.dataframe.user_performance import (
     ProjectPerformance,
     UserPerformance,
@@ -119,11 +118,7 @@ def get_project_output_dir(project_title: str) -> str:
 
 class WriteCsvGraph:
     task_df: Optional[pandas.DataFrame] = None
-    annotation_df: Optional[pandas.DataFrame] = None
     task_history_df: Optional[pandas.DataFrame] = None
-    labor_df: Optional[pandas.DataFrame] = None
-    productivity_df: Optional[pandas.DataFrame] = None
-    whole_productivity_df: Optional[pandas.DataFrame] = None
 
     def __init__(
         self,
@@ -131,7 +126,7 @@ class WriteCsvGraph:
         project_id: str,
         table_obj: Table,
         output_dir: Path,
-        labor_df: Optional[pandas.DataFrame],
+        df_labor: Optional[pandas.DataFrame],
         minimal_output: bool = False,
     ):
         self.service = service
@@ -139,11 +134,8 @@ class WriteCsvGraph:
         self.output_dir = output_dir
         self.table_obj = table_obj
         self.csv_obj = Csv(str(output_dir))
-        # holoviews のloadに時間がかかって、helpコマンドの出力が遅いため、遅延ロードする
-        histogram_module = importlib.import_module("annofabcli.statistics.histogram")
-        self.histogram_obj = histogram_module.Histogram(str(output_dir / "histogram"))  # type: ignore
 
-        self.labor_df = self.table_obj.create_labor_df(labor_df)
+        self.df_labor = self.table_obj.create_labor_df(df_labor)
         self.minimal_output = minimal_output
 
     def _catch_exception(self, function: Callable[..., Any]) -> Callable[..., Any]:
@@ -171,37 +163,14 @@ class WriteCsvGraph:
             self.task_history_df = self.table_obj.create_task_history_df()
         return self.task_history_df
 
-    def _get_annotation_df(self):
-        if self.annotation_df is None:
-            self.annotation_df = self.table_obj.create_task_for_annotation_df()
-        return self.annotation_df
-
-    def _get_labor_df(self):
-        if self.labor_df is None:
-            self.labor_df = self.table_obj.create_labor_df()
-
-        return self.labor_df
-
     def write_histogram_for_task(self) -> None:
         """
         タスクに関するヒストグラムを出力する。
 
         """
-        task_df = self._get_task_df()
-        self._catch_exception(self.histogram_obj.write_histogram_for_worktime)(task_df)
-        self._catch_exception(self.histogram_obj.write_histogram_for_other)(task_df)
-
-        if not self.minimal_output:
-            self._catch_exception(self.histogram_obj.write_histogram_for_annotation_worktime_by_user)(task_df)
-            self._catch_exception(self.histogram_obj.write_histogram_for_inspection_worktime_by_user)(task_df)
-            self._catch_exception(self.histogram_obj.write_histogram_for_acceptance_worktime_by_user)(task_df)
-
-    def write_histogram_for_annotation(self) -> None:
-        """
-        アノテーションに関するヒストグラムを出力する。
-        """
-        annotation_df = self._get_annotation_df()
-        self._catch_exception(self.histogram_obj.write_histogram_for_annotation_count_by_label)(annotation_df)
+        obj = Task(self._get_task_df())
+        obj.plot_histogram_of_worktime(self.output_dir / "histogram/ヒストグラム-作業時間.html")
+        obj.plot_histogram_of_others(self.output_dir / "histogram/ヒストグラム.html")
 
     def write_user_performance(self) -> None:
         """
@@ -217,7 +186,7 @@ class WriteCsvGraph:
         else:
             obj = UserPerformance.from_df(
                 df_task_history=df_task_history,
-                df_labor=self._get_labor_df(),
+                df_labor=self.df_labor,
                 df_worktime_ratio=annotation_count_ratio_df,
             )
 
@@ -246,24 +215,6 @@ class WriteCsvGraph:
                 " * '散布図-アノテーションあたり作業時間と品質の関係-実績時間-教師付者用'"
             )
 
-    def write_whole_productivity_per_date(self) -> None:
-        """日ごとの全体の生産性に関するファイルを出力する。"""
-        task_df = self._get_task_df()
-        labor_df = self._get_labor_df()
-        whole_productivity_df = WholeProductivityPerCompletedDate.create(task_df, labor_df)
-
-        WholeProductivityPerCompletedDate.plot(whole_productivity_df, self.output_dir / "line-graph/折れ線-横軸_日-全体.html")
-        WholeProductivityPerCompletedDate.plot_cumulatively(
-            whole_productivity_df, self.output_dir / "line-graph/累積折れ線-横軸_日-全体.html"
-        )
-
-        WholeProductivityPerCompletedDate.to_csv(whole_productivity_df, self.output_dir / FILENAME_PERFORMANCE_PER_DATE)
-
-    def write_whole_productivity_per_first_annotation_started_date(self) -> None:
-        df = WholeProductivityPerFirstAnnotationStartedDate.create(self.task_df)
-        WholeProductivityPerFirstAnnotationStartedDate.to_csv(df, self.output_dir / "教師付開始日毎の生産量と生産性.csv")
-        WholeProductivityPerFirstAnnotationStartedDate.plot(df, self.output_dir / "line-graph/折れ線-横軸_教師付開始日-全体.html")
-
     def write_cumulative_linegraph_by_user(self, user_id_list: Optional[List[str]] = None) -> None:
         """ユーザごとの累積折れ線グラフをプロットする。"""
         df_task = self._get_task_df()
@@ -297,9 +248,21 @@ class WriteCsvGraph:
 
     def write_worktime_per_date(self, user_id_list: Optional[List[str]] = None) -> None:
         """日ごとの作業時間情報を出力する。"""
-        obj = WorktimePerDate.from_webapi(self.service, self.project_id)
-        obj.plot_cumulatively(self.output_dir / "line-graph/累積折れ線-横軸_日-縦軸_作業時間.html", user_id_list)
-        obj.to_csv(self.output_dir / "ユーザ_日付list-作業時間.csv")
+        worktime_per_date_obj = WorktimePerDate.from_webapi(self.service, self.project_id, self.df_labor)
+        worktime_per_date_obj.plot_cumulatively(self.output_dir / "line-graph/累積折れ線-横軸_日-縦軸_作業時間.html", user_id_list)
+        worktime_per_date_obj.to_csv(self.output_dir / "ユーザ_日付list-作業時間.csv")
+
+        df_task = self._get_task_df()
+        productivity_per_completed_date_obj = WholeProductivityPerCompletedDate.from_df(
+            df_task, worktime_per_date_obj.df
+        )
+        productivity_per_completed_date_obj.plot(self.output_dir / "line-graph/折れ線-横軸_日-全体.html")
+        productivity_per_completed_date_obj.plot_cumulatively(self.output_dir / "line-graph/累積折れ線-横軸_日-全体.html")
+        productivity_per_completed_date_obj.to_csv(self.output_dir / FILENAME_PERFORMANCE_PER_DATE)
+
+        productivity_per_started_date_obj = WholeProductivityPerFirstAnnotationStartedDate.from_df(df_task)
+        productivity_per_started_date_obj.to_csv(self.output_dir / "教師付開始日毎の生産量と生産性.csv")
+        productivity_per_started_date_obj.plot(self.output_dir / "line-graph/折れ線-横軸_教師付開始日-全体.html")
 
     def write_csv_for_task(self) -> None:
         """
@@ -308,56 +271,6 @@ class WriteCsvGraph:
         task_df = self._get_task_df()
         self._catch_exception(self.csv_obj.write_task_list)(task_df, dropped_columns=["input_data_id_list"])
 
-    def write_csv_for_summary(self) -> None:
-        """
-        タスク関係のCSVを出力する。
-        """
-        task_df = self._get_task_df()
-        self._catch_exception(self.csv_obj.write_task_count_summary)(task_df)
-        self._catch_exception(self.csv_obj.write_worktime_summary)(task_df)
-        self._catch_exception(self.csv_obj.write_count_summary)(task_df)
-
-    def _write_メンバー別作業時間平均_画像1枚あたり_by_phase(self, phase: TaskPhase):
-        df_by_inputs = self.table_obj.create_worktime_per_image_df(AggregationBy.BY_INPUTS, phase)
-        self.csv_obj.write_メンバー別作業時間平均_画像1枚あたり(df_by_inputs, phase)
-
-        df_by_tasks = self.table_obj.create_worktime_per_image_df(AggregationBy.BY_TASKS, phase)
-        self.csv_obj.write_メンバー別作業時間平均_タスク1個あたり(df_by_tasks, phase)
-
-    def write_メンバー別作業時間平均_画像1枚あたり_by_phase(self):
-        for phase in TaskPhase:
-            self._catch_exception(self._write_メンバー別作業時間平均_画像1枚あたり_by_phase)(phase)
-
-    def write_csv_for_inspection(self) -> None:
-        """
-        検査コメント関係の情報をCSVに出力する。
-        """
-        inspection_df = self.table_obj.create_inspection_df()
-        inspection_df_all = self.table_obj.create_inspection_df(only_error_corrected=False)
-
-        self._catch_exception(self.csv_obj.write_inspection_list)(
-            df=inspection_df, dropped_columns=["data"], only_error_corrected=True
-        )
-        self._catch_exception(self.csv_obj.write_inspection_list)(
-            df=inspection_df_all,
-            dropped_columns=["data"],
-            only_error_corrected=False,
-        )
-
-    def write_csv_for_annotation(self) -> None:
-        """
-        アノテーション関係の情報をCSVに出力する。
-        """
-        annotation_df = self._get_annotation_df()
-        self._catch_exception(self.csv_obj.write_ラベルごとのアノテーション数)(annotation_df)
-
-    def write_labor_and_task_history(self) -> None:
-        task_history_df = self._get_task_history_df()
-        self._catch_exception(self.csv_obj.write_task_history_list)(task_history_df)
-
-        df_labor = self._get_labor_df()
-        self._catch_exception(self.csv_obj.write_labor_list)(df_labor)
-
     def write_user_productivity_per_date(self, user_id_list: Optional[List[str]] = None):
         """ユーザごとの日ごとの生産性情報を出力する。"""
         # 各ユーザごとの日ごとの情報
@@ -463,35 +376,24 @@ def visualize_statistics(
         output_project_dir=output_project_dir,
     )
     write_obj = WriteCsvGraph(
-        annofab_service, project_id, table_obj, output_project_dir, labor_df=df_labor, minimal_output=minimal_output
+        annofab_service, project_id, table_obj, output_project_dir, df_labor=df_labor, minimal_output=minimal_output
     )
     write_obj.write_csv_for_task()
 
-    write_obj.write_csv_for_summary()
-
     write_obj._catch_exception(write_obj.write_user_performance)()
 
     # ヒストグラム
-    write_obj.write_histogram_for_task()
+    write_obj._catch_exception(write_obj.write_histogram_for_task)()
 
     # 折れ線グラフ
     write_obj.write_cumulative_linegraph_by_user(user_id_list)
-    write_obj.write_whole_productivity_per_date()
 
-    write_obj.write_whole_productivity_per_first_annotation_started_date()
+    write_obj._catch_exception(write_obj.write_worktime_per_date)(user_id_list)
 
     if not minimal_output:
-        write_obj.write_histogram_for_annotation()
-        write_obj._catch_exception(write_obj.write_worktime_per_date)(user_id_list)
 
         write_obj._catch_exception(write_obj.write_user_productivity_per_date)(user_id_list)
 
-        # CSV
-        write_obj.write_labor_and_task_history()
-        write_obj.write_csv_for_annotation()
-        write_obj.write_csv_for_inspection()
-        write_obj.write_メンバー別作業時間平均_画像1枚あたり_by_phase()
-
 
 def visualize_statistics_wrapper(
     project_id: str,
